--- layout: default title: Components slug: components lead: "Over a dozen reusable components built to provide iconography, dropdowns, navigation, alerts, popovers, and much more." base_url: "../" ---

# Glyphicons

## Available glyphs

Includes 180 glyphs in font format from the Glyphicon Halflings set. Glyphicons Halflings are normally not available for free, but their creator has made them available for Bootstrap free of cost. As a thank you, we only ask that you to include a link back to Glyphicons whenever possible.

- .glyphicon .glyphicon-adjust
- .glyphicon .glyphicon-align-center
- .glyphicon .glyphicon-align-justify
- .glyphicon .glyphicon-align-left
- .glyphicon .glyphicon-align-right
- .glyphicon .glyphicon-arrow-down
- .glyphicon .glyphicon-arrow-left
- .glyphicon .glyphicon-arrow-right
- .glyphicon .glyphicon-arrow-up
- .glyphicon .glyphicon-asterisk
- .glyphicon .glyphicon-backward
- .glyphicon .glyphicon-ban-circle
- .glyphicon .glyphicon-barcode
- .glyphicon .glyphicon-bell
- .glyphicon .glyphicon-bold
- .glyphicon .glyphicon-book
- .glyphicon .glyphicon-bookmark
- .glyphicon .glyphicon-briefcase
- .glyphicon .glyphicon-bullhorn
- .glyphicon .glyphicon-calendar
- .glyphicon .glyphicon-camera
- .glyphicon .glyphicon-certificate
- .glyphicon .glyphicon-check
- .glyphicon .glyphicon-chevron-down
- .glyphicon .glyphicon-chevron-left
- .glyphicon .glyphicon-chevron-right
- .glyphicon .glyphicon-chevron-up
- .glyphicon .glyphicon-circle-arrow-down
- .glyphicon .glyphicon-circle-arrow-left
- .glyphicon .glyphicon-circle-arrow-right
- .glyphicon .glyphicon-circle-arrow-up
- .glyphicon .glyphicon-cloud
- .glyphicon .glyphicon-cloud-download
- .glyphicon .glyphicon-cloud-upload
- .glyphicon .glyphicon-cog
- .glyphicon .glyphicon-collapse-down
- .glyphicon .glyphicon-collapse-up
- .glyphicon .glyphicon-comment
- .glyphicon .glyphicon-compressed
- .glyphicon .glyphicon-copyright-mark
- .glyphicon .glyphicon-credit-card
- .glyphicon .glyphicon-cutlery
- .glyphicon .glyphicon-dashboard
- .glyphicon .glyphicon-download
- .glyphicon .glyphicon-download-alt
- .glyphicon .glyphicon-earphone
- .glyphicon .glyphicon-edit
- .glyphicon .glyphicon-eject
- .glyphicon .glyphicon-envelope
- .glyphicon .glyphicon-euro
- .glyphicon .glyphicon-exclamation-sign
- .glyphicon .glyphicon-expand
- .glyphicon .glyphicon-export
- .glyphicon .glyphicon-eye-close
- .glyphicon .glyphicon-eye-open
- .glyphicon .glyphicon-facetime-video
- .glyphicon .glyphicon-fast-backward
- .glyphicon .glyphicon-fast-forward
- .glyphicon .glyphicon-file
- .glyphicon .glyphicon-film
- .glyphicon .glyphicon-filter
- .glyphicon .glyphicon-fire
- .glyphicon .glyphicon-flag
- .glyphicon .glyphicon-flash
- .glyphicon .glyphicon-floppy-disk
- .glyphicon .glyphicon-floppy-open
- .glyphicon .glyphicon-floppy-remove
- .glyphicon .glyphicon-floppy-save
- .glyphicon .glyphicon-floppy-saved
- .glyphicon .glyphicon-folder-close
- .glyphicon .glyphicon-folder-open
- .glyphicon .glyphicon-font
- .glyphicon .glyphicon-forward
- .glyphicon .glyphicon-fullscreen
- .glyphicon .glyphicon-gbp
- .glyphicon .glyphicon-gift
- .glyphicon .glyphicon-glass
- .glyphicon .glyphicon-globe
- .glyphicon .glyphicon-hand-down
- .glyphicon .glyphicon-hand-left
- .glyphicon .glyphicon-hand-right
- .glyphicon .glyphicon-hand-up
- .glyphicon .glyphicon-hd-video
- .glyphicon .glyphicon-hdd
- .glyphicon .glyphicon-header
- .glyphicon .glyphicon-headphones
- .glyphicon .glyphicon-heart
- .glyphicon .glyphicon-heart-empty
- .glyphicon .glyphicon-home
- .glyphicon .glyphicon-import
- .glyphicon .glyphicon-inbox
- .glyphicon .glyphicon-indent-left
- .glyphicon .glyphicon-indent-right
- .glyphicon .glyphicon-info-sign
- .glyphicon .glyphicon-italic
- .glyphicon .glyphicon-leaf
- .glyphicon .glyphicon-link
- .glyphicon .glyphicon-list
- .glyphicon .glyphicon-list-alt
- .glyphicon .glyphicon-lock
- .glyphicon .glyphicon-log-in
- .glyphicon .glyphicon-log-out
- .glyphicon .glyphicon-magnet
- .glyphicon .glyphicon-map-marker
- .glyphicon .glyphicon-minus
- .glyphicon .glyphicon-minus-sign
- .glyphicon .glyphicon-move
- .glyphicon .glyphicon-music
- .glyphicon .glyphicon-new-window
- .glyphicon .glyphicon-off
- .glyphicon .glyphicon-ok
- .glyphicon .glyphicon-ok-circle
- .glyphicon .glyphicon-ok-sign
- .glyphicon .glyphicon-open
- .glyphicon .glyphicon-paperclip
- .glyphicon .glyphicon-pause
- .glyphicon .glyphicon-pencil
- .glyphicon .glyphicon-phone
- .glyphicon .glyphicon-phone-alt
- .glyphicon .glyphicon-picture
- .glyphicon .glyphicon-plane
- .glyphicon .glyphicon-play
- .glyphicon .glyphicon-play-circle
- .glyphicon .glyphicon-plus
- .glyphicon .glyphicon-plus-sign
- .glyphicon .glyphicon-print
- .glyphicon .glyphicon-pushpin
- .glyphicon .glyphicon-qrcode
- .glyphicon .glyphicon-question-sign
- .glyphicon .glyphicon-random
- .glyphicon .glyphicon-record
- .glyphicon .glyphicon-refresh
- .glyphicon .glyphicon-registration-mark
- .glyphicon .glyphicon-remove
- .glyphicon .glyphicon-remove-circle
- .glyphicon .glyphicon-remove-sign
- .glyphicon .glyphicon-repeat
- .glyphicon .glyphicon-resize-full
- .glyphicon .glyphicon-resize-horizontal
- .glyphicon .glyphicon-resize-small
- .glyphicon .glyphicon-resize-vertical
- .glyphicon .glyphicon-retweet
- .glyphicon .glyphicon-road
- .glyphicon .glyphicon-save
- .glyphicon .glyphicon-saved
- .glyphicon .glyphicon-screenshot
- .glyphicon .glyphicon-sd-video
- .glyphicon .glyphicon-search
- .glyphicon .glyphicon-send
- .glyphicon .glyphicon-share
- .glyphicon .glyphicon-share-alt
- .glyphicon .glyphicon-shopping-cart
- .glyphicon .glyphicon-signal
- .glyphicon .glyphicon-sort
- .glyphicon .glyphicon-sort-by-alphabet
- .glyphicon .glyphicon-sort-by-alphabet-alt
- .glyphicon .glyphicon-sort-by-attributes
- .glyphicon .glyphicon-sort-by-attributes-alt
- .glyphicon .glyphicon-sort-by-order
- .glyphicon .glyphicon-sort-by-order-alt
- .glyphicon .glyphicon-sound-5-1
- .glyphicon .glyphicon-sound-6-1
- .glyphicon .glyphicon-sound-7-1
- .glyphicon .glyphicon-sound-dolby
- .glyphicon .glyphicon-sound-stereo
- .glyphicon .glyphicon-star
- .glyphicon .glyphicon-star-empty
- .glyphicon .glyphicon-stats
- .glyphicon .glyphicon-step-backward
- .glyphicon .glyphicon-step-forward
- .glyphicon .glyphicon-stop
- .glyphicon .glyphicon-subtitles
- .glyphicon .glyphicon-tag
- .glyphicon .glyphicon-tags
- .glyphicon .glyphicon-tasks
- .glyphicon .glyphicon-text-height
- .glyphicon .glyphicon-text-width
- .glyphicon .glyphicon-th
- .glyphicon .glyphicon-th-large
- .glyphicon .glyphicon-th-list
- .glyphicon .glyphicon-thumbs-down
- .glyphicon .glyphicon-thumbs-up
- .glyphicon .glyphicon-time
- .glyphicon .glyphicon-tint
- .glyphicon .glyphicon-tower
- .glyphicon .glyphicon-transfer
- .glyphicon .glyphicon-trash
- .glyphicon .glyphicon-tree-conifer
- .glyphicon .glyphicon-tree-deciduous
- .glyphicon .glyphicon-unchecked
- .glyphicon .glyphicon-upload
- .glyphicon .glyphicon-usd
- .glyphicon .glyphicon-user
- .glyphicon .glyphicon-volume-down
- .glyphicon .glyphicon-volume-off
- .glyphicon .glyphicon-volume-up
- .glyphicon .glyphicon-warning-sign
- .glyphicon .glyphicon-wrench
- .glyphicon .glyphicon-zoom-in
- .glyphicon .glyphicon-zoom-out

## How to use

For performance reasons, all icons require a base class and individual icon class. To use, place the following code just about anywhere. Be sure to leave a space between the icon and text for proper padding.

{% highlight html %} {% endhighlight %}

## Examples

Use them in buttons, button groups for a toolbar, navigation, or prepended form inputs.

{% highlight html %}
{% endhighlight %}

# Dropdowns

Toggleable, contextual menu for displaying lists of links. Made interactive with the dropdown JavaScript plugin.

### Example

Wrap the dropdown's trigger and the dropdown menu within `.dropdown`, or another element that declares `position: relative;`. Then add the menu's HTML.

Dropdown
{% highlight html %}
{% endhighlight %}

### Aligninment options

Add `.pull-right` to a `.dropdown-menu` to right align the dropdown menu.

{% highlight html %}
{% endhighlight %}

### Headers

Add a header to label sections of actions in any dropdown menu.

Dropdown
{% highlight html %}
{% endhighlight %}

### Disabled menu items

Add `.disabled` to a `<li>` in the dropdown to disable the link.

Dropdown
{% highlight html %}
{% endhighlight %}

# Button groups

Group a series of buttons together on a single line with the button group. Add on optional JavaScript radio and checkbox style behavior with our buttons plugin.

#### Tooltips & popovers in button groups require special setting

When using tooltips or popovers on elements within a `.btn-group`, you'll have to specify the option `container: 'body'` to avoid unwanted side effects (such as the element growing wider and/or losing its rounded corners when the tooltip or popover is triggered).

### Basic example

Wrap a series of buttons with `.btn` in `.btn-group`.

{% highlight html %}
{% endhighlight %}

### Button toolbar

Combine sets of `<div class="btn-group">` into a `<div class="btn-toolbar">` for more complex components.

{% highlight html %}
...
...
...
{% endhighlight %}

### Sizing

Instead of applying button sizing classes to every button in a group, just add `.btn-group-*` to the `.btn-group`.

{% highlight html %}
...
...
...
...
{% endhighlight %}

### Nesting

Place a `.btn-group` within another `.btn-group` when you want dropdown menus mixed with a series of buttons.

{% highlight html %}
{% endhighlight %}

### Vertical variation

Make a set of buttons appear vertically stacked rather than horizontally.

{% highlight html %}
...
{% endhighlight %}

### Justified link variation

Make a group of buttons stretch at the same size to span the entire width of its parent.

#### Element-specific usage

This only works with `<a>` elements as the `<button>` doesn't pick up these styles.

Left Middle Right
{% highlight html %}
...
{% endhighlight %}

# Button dropdowns

Use any button to trigger a dropdown menu by placing it within a `.btn-group` and providing the proper menu markup.

#### Plugin dependency

Button dropdowns require the dropdown plugin to be included in your version of Bootstrap.

### Single button dropdowns

Turn a button into a dropdown toggle with some basic markup changes.

{% highlight html %}
{% endhighlight %}

### Split button dropdowns

Similarly, create split button dropdowns with the same markup changes, only with a separate button.

{% highlight html %}
{% endhighlight %}

### Sizing

Button dropdowns work with buttons of all sizes.

{% highlight html %}
{% endhighlight %}

### Dropup variation

Trigger dropdown menus above elements by adding `.dropup` to the parent.

{% highlight html %}
{% endhighlight %}

# Input groups

Extend form controls by adding text or buttons before, after, or on both sides of any text-based input. Use `.input-group` with an `.input-group-addon` to prepend or append elements to a `.form-control`.

#### Cross-browser compatibility

Avoid using `<select>` elements here as they cannot be fully styled in WebKit browsers.

#### Tooltips & popovers in input groups require special setting

When using tooltips or popovers on elements within an `.input-group`, you'll have to specify the option `container: 'body'` to avoid unwanted side effects (such as the element growing wider and/or losing its rounded corners when the tooltip or popover is triggered).

## Basic example

@
.00
$ .00
{% highlight html %}
@
.00
$ .00
{% endhighlight %}

## Sizing

Add the relative form sizing classes to the `.input-group` itself and contents within will automatically resize—no need for repeating the form control size classes on each element.

@
@
@
{% highlight html %}
@
@
@
{% endhighlight %}

## Checkboxes and radio addons

Place any checkbox or radio option within an input group's addon instead of text.

{% highlight html %}
{% endhighlight %}

## Button addons

Buttons in input groups are a bit different and require one extra level of nesting. Instead of `.input-group-addon`, you'll need to use `.input-group-btn` to wrap the buttons. This is required due to default browser styles that cannot be overridden.

{% highlight html %}
{% endhighlight %}

## Buttons with dropdowns

{% highlight html %}
{% endhighlight %}

## Segmented buttons

{% highlight html %}
{% endhighlight %}

# Navs

Navs available in Bootstrap have shared markup, starting with the base `.nav` class, as well as shared states. Swap modifier classes to switch between each style.

## Tabs

Note the `.nav-tabs` class requires the `.nav` base class.

{% highlight html %}
{% endhighlight %}

## Pills

Take that same HTML, but use `.nav-pills` instead:

{% highlight html %}
{% endhighlight %}

Pills are also vertically stackable. Just add `.nav-stacked`.

{% highlight html %}
{% endhighlight %}

## Justified

Easily make tabs or pills equal widths of their parent with `.nav-justified`.

{% highlight html %}
{% endhighlight %}

## Disabled links

For any nav component (tabs, pills, or list), add `.disabled` for gray links and no hover effects.

#### Link functionality not impacted

This class will only change the `<a>`'s appearance, not its functionality. Use custom JavaScript to disable links here.

{% highlight html %}
{% endhighlight %}

## Using dropdowns

Add dropdown menus with a little extra HTML and the dropdowns JavaScript plugin.

### Tabs with dropdowns

{% highlight html %}
{% endhighlight %}

### Pills with dropdowns

{% highlight html %}
{% endhighlight %}

# Navbar

## Default navbar

Navbars are responsive meta components that serve as navigation headers for your application or site. They begin collapsed (and are toggleable) in mobile views and become horizontal as the available viewport width increases.

#### Customize the collapsing point

Depending on the content in your navbar, you might need to change the point at which your navbar switches between collapsed and horizontal mode. Customize the `@grid-float-breakpoint` variable or add your own media query.

{% highlight html %}
{% endhighlight %}

#### Plugin dependency

The responsive navbar requires the collapse plugin to be included in your version of Bootstrap.

#### Make navbars accessible

Be sure to add a `role="navigation"` to every navbar to help with accessibility.

## Buttons

For buttons not residing in a `<form>`, add this class to vertically center buttons within a navbar.

{% highlight html %}
{% endhighlight %}

## Text

Wrap strings of text in an element with `.navbar-text`, usually on a `<p>` tag for proper leading and color.

{% highlight html %}
{% endhighlight %}

## Non-nav links

For folks using standard links that are not within the regular navbar navigation component, use the `.navbar-link` class to add the proper colors for the default and inverse navbar options.

{% highlight html %}
{% endhighlight %}

## Component alignment

Align nav links, forms, buttons, or text, using the `.navbar-left` or `.navbar-right` utility classes. Both classes will add a CSS float in the specified direction. For example, to align nav links, put them in a separate `<ul>` with the respective utility class applied.

These classes are mixin-ed versions of `.pull-left` and `.pull-right`, but they're scoped to media queries for easier handling of navbar components across device sizes.

## Fixed to top

Add `.navbar-fixed-top`.

{% highlight html %}
{% endhighlight %}

#### Body padding required

The fixed navbar will overlay your other content, unless you add `padding` to the top of the `<body>`. Try out your own values or use our snippet below. Tip: By default, the navbar is 50px high.

{% highlight css %} body { padding-top: 70px; } {% endhighlight %}

Make sure to include this after the core Bootstrap CSS.

## Fixed to bottom

Add `.navbar-fixed-bottom` instead.

{% highlight html %}
{% endhighlight %}

#### Body padding required

The fixed navbar will overlay your other content, unless you add `padding` to the bottom of the `<body>`. Try out your own values or use our snippet below. Tip: By default, the navbar is 50px high.

{% highlight css %} body { padding-bottom: 70px; } {% endhighlight %}

Make sure to include this after the core Bootstrap CSS.

## Static top

Create a full-width navbar that scrolls away with the page by adding `.navbar-static-top`. Unlike the `.navbar-fixed-*` classes, you do not need to change any padding on the `body`.

{% highlight html %}
{% endhighlight %}

## Inverted navbar

Modify the look of the navbar by adding `.navbar-inverse`.

{% highlight html %}
{% endhighlight %}

# Breadcrumbs

Indicate the current page's location within a navigational hierarchy.

Separators are automatically added in CSS through `:before` and `content`.

{% highlight html %}
{% endhighlight %}

# Pagination

Provide pagination links for your site or app with the multi-page pagination component, or the simpler pager alternative.

## Default pagination

Simple pagination inspired by Rdio, great for apps and search results. The large block is hard to miss, easily scalable, and provides large click areas.

- «
- 1
- 2
- 3
- 4
- 5
- »

{% highlight html %}

- «
- 1
- 2
- 3
- 4
- 5
- »

{% endhighlight %}

### Disabled and active states

Links are customizable for different circumstances. Use `.disabled` for unclickable links and `.active` to indicate the current page.

- «
- 1 (current)
- 2
- 3
- 4
- 5
- »

{% highlight html %}

- «
- 1 (current)
...

{% endhighlight %}

You can optionally swap out active or disabled anchors for `<span>` to remove click functionality while retaining intended styles.

{% highlight html %}

- «
- 1 (current)
...

{% endhighlight %}

### Sizing

Fancy larger or smaller pagination? Add `.pagination-lg` or `.pagination-sm` for additional sizes.

- «
- 1
- 2
- 3
- 4
- 5
- »

- «
- 1
- 2
- 3
- 4
- 5
- »

- «
- 1
- 2
- 3
- 4
- 5
- »

{% highlight html %}

...

...

...

{% endhighlight %}

## Pager

Quick previous and next links for simple pagination implementations with light markup and styles. It's great for simple sites like blogs or magazines.

### Default example

By default, the pager centers links.

- Previous
- Next

{% highlight html %}

- Previous
- Next

{% endhighlight %}

### Aligned links

Alternatively, you can align each link to the sides:

- ← Older
- Newer →

{% highlight html %}

- ← Older
- Newer →

{% endhighlight %}

### Optional disabled state

Pager links also use the general `.disabled` utility class from the pagination.

- ← Older
- Newer →

{% highlight html %}

- ← Older
- Newer →

{% endhighlight %}

# Labels

### Example

# Example heading New

{% highlight html %}

### Example heading New

{% endhighlight %}

### Available variations

Add any of the below mentioned modifier classes to change the appearance of a label.

Default Primary Success Info Warning Danger
{% highlight html %} Default Primary Success Info Warning Danger {% endhighlight %}

# Badges

Easily highlight new or unread items by adding a `<span class="badge">` to links, Bootstrap navs, and more.

Inbox 42
{% highlight html %} Inbox 42 {% endhighlight %}

#### Self collapsing

When there are no new or unread items, badges will simply collapse (via CSS's `:empty` selector) provided no content exists within.

#### Cross-browser compatibility

Badges won't self collapse in Internet Explorer 8 because it lacks support for the `:empty` selector.

#### Adapts to active nav states

Built-in styles are included for placing badges in active states in pill and list navigations.

{% highlight html %}
{% endhighlight %}

# Jumbotron

A lightweight, flexible component that can optional extend the entire viewport to showcase key content on your site. To make the jumbotron full width, don't include it within a `.container`. Placing it within a container will keep it at the width of the rest of your content and provide rounded corners.

# Hello, world!

This is a simple hero unit, a simple jumbotron-style component for calling extra attention to featured content or information.

Learn more

{% highlight html %}

# Hello, world!

...

Learn more

{% endhighlight %}

# Page header

A simple shell for an `h1` to appropriately space out and segment sections of content on a page. It can utilize the `h1`'s default `small` element, as well as most other components (with additional styles).

# Example page header Subtext for header

{% highlight html %}

# Example page header Subtext for header

{% endhighlight %}

# Thumbnails

Extend Bootstrap's grid system with the thumbnail component to easily display grids of images, videos, text, and more.

### Default example

By default, Bootstrap's thumbnails are designed to showcase linked images with minimal required markup.

{% highlight html %}
...
{% endhighlight %}

### Custom content

With a bit of extra markup, it's possible to add any kind of HTML content like headings, paragraphs, or buttons into thumbnails.

### Thumbnail label

Cras justo odio, dapibus ac facilisis in, egestas eget quam. Donec id elit non mi porta gravida at eget metus. Nullam id dolor id nibh ultricies vehicula ut id elit.

Button Button

### Thumbnail label

Cras justo odio, dapibus ac facilisis in, egestas eget quam. Donec id elit non mi porta gravida at eget metus. Nullam id dolor id nibh ultricies vehicula ut id elit.

Button Button

### Thumbnail label

Cras justo odio, dapibus ac facilisis in, egestas eget quam. Donec id elit non mi porta gravida at eget metus. Nullam id dolor id nibh ultricies vehicula ut id elit.

Button Button

{% highlight html %}

### Thumbnail label

...

Button Button

{% endhighlight %}

# Alerts

Provide contextual feedback messages for typical user actions with the handful of available and flexible alert messages. For inline dismissal, use the alerts jQuery plugin.

## Examples

Wrap any text and an optional dismiss button in `.alert` and one of the four contextual classes (e.g., `.alert-success`) for basic alert messages.

#### No default class

Alerts don't have default classes, only base and modifier classes. A default gray alert doesn't make too much sense, so you're required to specify a type via contextual class. Choose from success, info, warning, or danger.

Well done! You successfully read this important alert message.
Heads up! This alert needs your attention, but it's not super important.
Warning! Best check yo self, you're not looking too good.
Oh snap! Change a few things up and try submitting again.
{% highlight html %}
...
...
...
...
{% endhighlight %}

## Dismissable alerts

Build on any alert by adding an optional `.alert-dismissable` and close button.

Warning! Best check yo self, you're not looking too good.
{% highlight html %}
Warning! Best check yo self, you're not looking too good.
{% endhighlight %}

#### Ensure proper behavior across all devices

Be sure to use the `<button>` element with the `data-dismiss="alert"` data attribute.

## Links in alerts

Use the `.alert-link` utility class to quickly provide matching colored links within any alert.

Well done! You successfully read this important alert message.
Heads up! This alert needs your attention, but it's not super important.
Warning! Best check yo self, you're not looking too good.
Oh snap! Change a few things up and try submitting again.
{% highlight html %}
...
...
...
...
{% endhighlight %}

# Progress bars

Provide up-to-date feedback on the progress of a workflow or action with simple yet flexible progress bars.

#### Cross-browser compatibility

Progress bars use CSS3 transitions and animations to achieve some of their effects. These features are not supported in Internet Explorer 9 and below or older versions of Firefox. Opera 12 does not support animations.

### Basic example

Default progress bar.

60% Complete
{% highlight html %}
60% Complete
{% endhighlight %}

### Contextual alternatives

Progress bars use some of the same button and alert classes for consistent styles.

40% Complete (success)
20% Complete
60% Complete (warning)
80% Complete (danger)
{% highlight html %}
40% Complete (success)
20% Complete
60% Complete (warning)
80% Complete
{% endhighlight %}

### Striped

Uses a gradient to create a striped effect. Not available in IE8.

40% Complete (success)
20% Complete
60% Complete (warning)
80% Complete (danger)
{% highlight html %}
40% Complete (success)
20% Complete
60% Complete (warning)
80% Complete (danger)
{% endhighlight %}

### Animated

Add `.active` to `.progress-striped` to animate the stripes right to left. Not available in all versions of IE.

45% Complete
{% highlight html %}
45% Complete
{% endhighlight %}

### Stacked

Place multiple bars into the same `.progress` to stack them.

35% Complete (success)
20% Complete (warning)
10% Complete (danger)
{% highlight html %}
35% Complete (success)
20% Complete (warning)
10% Complete (danger)
{% endhighlight %}

# Media object

Abstract object styles for building various types of components (like blog comments, Tweets, etc) that feature a left- or right-aligned image alongside textual content.

### Default media

The default media allow to float a media object (images, video, audio) to the left or right of a content block.

#### Media heading

Cras sit amet nibh libero, in gravida nulla. Nulla vel metus scelerisque ante sollicitudin commodo. Cras purus odio, vestibulum in vulputate at, tempus viverra turpis. Fusce condimentum nunc ac nisi vulputate fringilla. Donec lacinia congue felis in faucibus.

#### Media heading

Cras sit amet nibh libero, in gravida nulla. Nulla vel metus scelerisque ante sollicitudin commodo. Cras purus odio, vestibulum in vulputate at, tempus viverra turpis. Fusce condimentum nunc ac nisi vulputate fringilla. Donec lacinia congue felis in faucibus.

#### Media heading

Cras sit amet nibh libero, in gravida nulla. Nulla vel metus scelerisque ante sollicitudin commodo. Cras purus odio, vestibulum in vulputate at, tempus viverra turpis. Fusce condimentum nunc ac nisi vulputate fringilla. Donec lacinia congue felis in faucibus.
{% highlight html %}

#### Media heading

...
{% endhighlight %}

### Media list

With a bit of extra markup, you can use media inside list (useful for comment threads or articles lists).

- #### Media heading

  Cras sit amet nibh libero, in gravida nulla. Nulla vel metus scelerisque ante sollicitudin commodo. Cras purus odio, vestibulum in vulputate at, tempus viverra turpis.

  #### Nested media heading

  Cras sit amet nibh libero, in gravida nulla. Nulla vel metus scelerisque ante sollicitudin commodo. Cras purus odio, vestibulum in vulputate at, tempus viverra turpis.

  #### Nested media heading

  Cras sit amet nibh libero, in gravida nulla. Nulla vel metus scelerisque ante sollicitudin commodo. Cras purus odio, vestibulum in vulputate at, tempus viverra turpis.

  #### Nested media heading

  Cras sit amet nibh libero, in gravida nulla. Nulla vel metus scelerisque ante sollicitudin commodo. Cras purus odio, vestibulum in vulputate at, tempus viverra turpis.

- #### Media heading

  Cras sit amet nibh libero, in gravida nulla. Nulla vel metus scelerisque ante sollicitudin commodo. Cras purus odio, vestibulum in vulputate at, tempus viverra turpis.

{% highlight html %}

- #### Media heading

  ...

{% endhighlight %}

# List group

List groups are a flexible and powerful component for displaying not only simple lists of elements, but complex ones with custom content.

### Basic example

The most basic list group is simply an unordered list with list items, and the proper classes. Build upon it with the options that follow, or your own CSS as needed.

- Cras justo odio
- Dapibus ac facilisis in
- Morbi leo risus
- Porta ac consectetur ac
- Vestibulum at eros

{% highlight html %}

- Cras justo odio
- Dapibus ac facilisis in
- Morbi leo risus
- Porta ac consectetur ac
- Vestibulum at eros

{% endhighlight %}

### Badges

Add the badges component to any list group item and it will automatically be positioned on the right.

- 14 Cras justo odio
- 2 Dapibus ac facilisis in
- 1 Morbi leo risus

{% highlight html %}

- 14 Cras justo odio

{% endhighlight %}

### Linked items

Linkify list group items by using anchor tags instead of list items (that also means a parent `<div>` instead of an `<ul>`). No need for individual parents around each element.

Cras justo odio Dapibus ac facilisis in Morbi leo risus Porta ac consectetur ac Vestibulum at eros
{% highlight html %}
Cras justo odio Dapibus ac facilisis in Morbi leo risus Porta ac consectetur ac Vestibulum at eros
{% endhighlight %}

### Custom content

Add nearly any HTML within, even for linked list groups like the one below.

#### List group item heading

Donec id elit non mi porta gravida at eget metus. Maecenas sed diam eget risus varius blandit.

#### List group item heading

Donec id elit non mi porta gravida at eget metus. Maecenas sed diam eget risus varius blandit.

#### List group item heading

Donec id elit non mi porta gravida at eget metus. Maecenas sed diam eget risus varius blandit.

{% highlight html %}

#### List group item heading

...

{% endhighlight %}

# Panels

While not always necessary, sometimes you need to put your DOM in a box. For those situations, try the panel component.

### Basic example

By default, all the `.panel` does is apply some basic border and padding to contain some content.

Basic panel example
{% highlight html %}
Basic panel example
{% endhighlight %}

### Panel with heading

Easily add a heading container to your panel with `.panel-heading`. You may also include any `<h1>`-`<h6>` with a `.panel-title` class to add a pre-styled heading.

Panel heading without title
Panel content

### Panel title

Panel content
{% highlight html %}
Panel heading without title
Panel content

### Panel title

Panel content
{% endhighlight %}

### Panel with footer

Wrap buttons or secondary text in `.panel-footer`. Note that panel footers do not inherit colors and borders when using contextual variations as they are not meant to be in the foreground.

Panel content
{% highlight html %}
Panel content
{% endhighlight %}

### Contextual alternatives

Like other components, easily make a panel more meaningful to a particular context by adding any of the contextual state classes.

### Panel title

Panel content

### Panel title

Panel content

### Panel title

Panel content

### Panel title

Panel content

### Panel title

Panel content
{% highlight html %}
...
...
...
...
...
{% endhighlight %}

### With tables

Add any non-bordered `.table` within a panel for a seamless design. If there is a `.panel-body`, we add an extra border to the top of the table for separation.

Panel heading

Some default panel content here. Nulla vitae elit libero, a pharetra augue. Aenean lacinia bibendum nulla sed consectetur. Aenean eu leo quam. Pellentesque ornare sem lacinia quam venenatis vestibulum. Nullam id dolor id nibh ultricies vehicula ut id elit.

# | First Name | Last Name | Username
--- | --- | --- | ---
1 | Mark | Otto | @mdo
2 | Jacob | Thornton | @fat
3 | Larry | the Bird | @twitter

{% highlight html %}
Panel heading

...

...

{% endhighlight %}

If there is no panel body, the component moves from panel header to table without interruption.

Panel heading

# | First Name | Last Name | Username
--- | --- | --- | ---
1 | Mark | Otto | @mdo
2 | Jacob | Thornton | @fat
3 | Larry | the Bird | @twitter

{% highlight html %}
Panel heading

...

{% endhighlight %}

### With list groups

Easily include full-width list groups within any panel.

Panel heading

Some default panel content here. Nulla vitae elit libero, a pharetra augue. Aenean lacinia bibendum nulla sed consectetur. Aenean eu leo quam. Pellentesque ornare sem lacinia quam venenatis vestibulum. Nullam id dolor id nibh ultricies vehicula ut id elit.

- Cras justo odio
- Dapibus ac facilisis in
- Morbi leo risus
- Porta ac consectetur ac
- Vestibulum at eros

{% highlight html %}
Panel heading

...

- Cras justo odio
- Dapibus ac facilisis in
- Morbi leo risus
- Porta ac consectetur ac
- Vestibulum at eros

{% endhighlight %}

# Wells

### Default well

Use the well as a simple effect on an element to give it an inset effect.

Look, I'm in a well!
{% highlight html %}
...
{% endhighlight %}

### Optional classes

Control padding and rounded corners with two optional modifier classes.

Look, I'm in a large well!
{% highlight html %}
...
{% endhighlight %}
Look, I'm in a small well!
{% highlight html %}
...
{% endhighlight %}